#ifndef inetdconf_h
#define inetdconf_h
#pragma interface
#ifndef MISC_H
    #include <misc.h>
#endif
#ifndef MODULE_H
    #include <module.h>
#endif

#include <modapi_def.h>
#include <modapi.h>
class MODULE_inetdconf: public LINUXCONF_MODULE{
    /*~PROTOBEG~ MODULE_inetdconf */
public:
	MODULE_inetdconf (void);
	int dohtml (const char *key);
	int domenu (MENU_CONTEXT context,
		 const char *key);
	int execmain (int argc, char *argv[], bool);
	int message (const char *msg,
		 int argc,
		 const char *argv[]);
	int probe (int level,
		 int target,
		 bool simulation);
	void setmenu (DIALOG&dia,
		 MENU_CONTEXT context);
	void usage (SSTRINGS&tb);
    /*~PROTOEND~ MODULE_inetdconf */
};

static const char subsys_inetdconf[] = "inetdconf";

#include "inetdconf.p"

PUBLIC void firewall_enable ( int argc, char **argv);
PUBLIC void firewall_disable (void);
PUBLIC void firewall_edit (void);
PUBLIC int firewall_probe (int level, int target, int simulation);
extern PUBLIC bool xinetd_conf_flag;

#endif
